# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_reponse_stream_request import AIAssistantReponseStreamRequest  # noqa: E501

class TestAIAssistantReponseStreamRequest(unittest.TestCase):
    """AIAssistantReponseStreamRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AIAssistantReponseStreamRequest:
        """Test AIAssistantReponseStreamRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AIAssistantReponseStreamRequest`
        """
        model = AIAssistantReponseStreamRequest()  # noqa: E501
        if include_optional:
            return AIAssistantReponseStreamRequest(
                assistant_chat_member_id = 56,
                attachments = [
                    ai_assistant_server_connector.models.chat_message_attachment.ChatMessageAttachment(
                        attachment_type = 'IMAGE', 
                        file_id = '', )
                    ],
                chat_id = 56,
                chat_session_id = 56,
                history = [
                    ai_assistant_server_connector.models.chat_history_item.ChatHistoryItem(
                        content = [
                            ai_assistant_server_connector.models.chat_history_chat_content.ChatHistoryChatContent(
                                text = '', 
                                type = '', )
                            ], 
                        role = 'user', )
                    ],
                name_chat = True,
                portal_info = ai_assistant_server_connector.models.portal_info_request.PortalInfoRequest(
                    domain = 'unknown', 
                    language_id = 56, 
                    owner = ai_assistant_server_connector.models.portal_owner_info.PortalOwnerInfo(
                        email = '', 
                        first_name = '', 
                        last_name = '', ), ),
                session_id = '',
                user_prompt = ''
            )
        else:
            return AIAssistantReponseStreamRequest(
                assistant_chat_member_id = 56,
                chat_id = 56,
                chat_session_id = 56,
                history = [
                    ai_assistant_server_connector.models.chat_history_item.ChatHistoryItem(
                        content = [
                            ai_assistant_server_connector.models.chat_history_chat_content.ChatHistoryChatContent(
                                text = '', 
                                type = '', )
                            ], 
                        role = 'user', )
                    ],
                session_id = '',
                user_prompt = '',
        )
        """

    def testAIAssistantReponseStreamRequest(self):
        """Test AIAssistantReponseStreamRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_list_get import AiAssistantListGet  # noqa: E501

class TestAiAssistantListGet(unittest.TestCase):
    """AiAssistantListGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantListGet:
        """Test AiAssistantListGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantListGet`
        """
        model = AiAssistantListGet()  # noqa: E501
        if include_optional:
            return AiAssistantListGet(
                allow_text = True,
                allow_voice = True,
                approved_urls = [
                    ''
                    ],
                avatar_id = '',
                banned_keywords = [
                    ''
                    ],
                conversation_starter = '',
                conversation_style = 'formal',
                created_at = 56,
                deleted_at = 56,
                function = 'support',
                id = 56,
                is_active = True,
                is_available = True,
                is_live = True,
                knowledgebase_state = ai_assistant_server_connector.models.knowledgebase_state.KnowledgebaseState(
                    course_data = null, ),
                last_updated_at = 56,
                name = '',
                prefer_voice = True,
                system_prompt = '',
                system_prompt_support = '',
                system_prompt_tutor = '',
                type = 'portal',
                voice_id = 56
            )
        else:
            return AiAssistantListGet(
                allow_text = True,
                allow_voice = True,
                approved_urls = [
                    ''
                    ],
                banned_keywords = [
                    ''
                    ],
                conversation_style = 'formal',
                created_at = 56,
                function = 'support',
                id = 56,
                is_active = True,
                is_live = True,
                last_updated_at = 56,
                name = '',
                prefer_voice = True,
                type = 'portal',
                voice_id = 56,
        )
        """

    def testAiAssistantListGet(self):
        """Test AiAssistantListGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_goal_create_update import AiAssistantGoalCreateUpdate  # noqa: E501

class TestAiAssistantGoalCreateUpdate(unittest.TestCase):
    """AiAssistantGoalCreateUpdate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantGoalCreateUpdate:
        """Test AiAssistantGoalCreateUpdate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantGoalCreateUpdate`
        """
        model = AiAssistantGoalCreateUpdate()  # noqa: E501
        if include_optional:
            return AiAssistantGoalCreateUpdate(
                additional_prompt = '',
                course_ids = [
                    56
                    ],
                engagement = 0.0,
                engagement_opt_out_duration = 0.0,
                engagement_preset_id = 56,
                id = 56,
                is_active = True,
                max_engagement_count = 0.0,
                max_engagement_period = 0.0,
                max_total_engagement_count = 0.0,
                name = '',
                page_url = '',
                primary_course_id = 56
            )
        else:
            return AiAssistantGoalCreateUpdate(
                additional_prompt = '',
                course_ids = [
                    56
                    ],
                is_active = True,
                name = '',
        )
        """

    def testAiAssistantGoalCreateUpdate(self):
        """Test AiAssistantGoalCreateUpdate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.response_wrapper_ai_assistant_session_start import ResponseWrapperAIAssistantSessionStart  # noqa: E501

class TestResponseWrapperAIAssistantSessionStart(unittest.TestCase):
    """ResponseWrapperAIAssistantSessionStart unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperAIAssistantSessionStart:
        """Test ResponseWrapperAIAssistantSessionStart
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperAIAssistantSessionStart`
        """
        model = ResponseWrapperAIAssistantSessionStart()  # noqa: E501
        if include_optional:
            return ResponseWrapperAIAssistantSessionStart(
                done = True,
                error = '',
                result = ai_assistant_server_connector.models.ai_assistant_session_start.AIAssistantSessionStart(
                    ai_assistant = ai_assistant_server_connector.models.ai_assistant_get.AiAssistantGet(
                        allow_text = True, 
                        allow_voice = True, 
                        approved_urls = [
                            ''
                            ], 
                        avatar_id = '', 
                        banned_keywords = [
                            ''
                            ], 
                        conversation_starter = '', 
                        conversation_style = 'formal', 
                        created_at = 56, 
                        deleted_at = 56, 
                        function = 'support', 
                        goals = [
                            ai_assistant_server_connector.models.ai_assistant_goal_get.AiAssistantGoalGet(
                                additional_prompt = '', 
                                ai_assistant_id = 56, 
                                course_ids = [
                                    56
                                    ], 
                                created_at = 56, 
                                engagement = 56, 
                                engagement_opt_out_duration = 56, 
                                engagement_preset = ai_assistant_server_connector.models.goal_engagement_preset_get.GoalEngagementPresetGet(
                                    created_at = 56, 
                                    engagement = 56, 
                                    engagement_opt_out_duration = 56, 
                                    id = 56, 
                                    max_engagement_count = 56, 
                                    max_engagement_period = 56, 
                                    max_total_engagement_count = 56, 
                                    name = '', 
                                    order = 56, ), 
                                engagement_preset_id = 56, 
                                id = 56, 
                                interactions_summary = ai_assistant_server_connector.models.goal_interactions_summary.GoalInteractionsSummary(
                                    is_available = True, 
                                    last_engagement_at = 56, 
                                    last_opt_out_at = 56, 
                                    recent_interaction_count = 56, 
                                    total_interaction_count = 56, ), 
                                is_active = True, 
                                is_fullfilled = True, 
                                last_updated_at = 56, 
                                max_engagement_count = 56, 
                                max_engagement_period = 56, 
                                max_total_engagement_count = 56, 
                                name = '', 
                                page_url = '', 
                                primary_course = ai_assistant_server_connector.models.course_public.CoursePublic(
                                    description = '', 
                                    id = 56, 
                                    modules = [
                                        ai_assistant_server_connector.models.course_module_public.CourseModulePublic(
                                            id = 56, 
                                            lessons = [
                                                ai_assistant_server_connector.models.module_lesson_public.ModuleLessonPublic(
                                                    id = 56, 
                                                    title = '', )
                                                ], 
                                            public_description = '', 
                                            short_description = '', 
                                            title = '', )
                                        ], 
                                    payment_type = null, 
                                    title = '', 
                                    url = '', ), 
                                primary_course_id = 56, )
                            ], 
                        id = 56, 
                        is_active = True, 
                        is_available = True, 
                        is_live = True, 
                        knowledgebase_state = ai_assistant_server_connector.models.knowledgebase_state.KnowledgebaseState(
                            course_data = null, ), 
                        last_updated_at = 56, 
                        lexicon_items = [
                            ai_assistant_server_connector.models.ai_assistant_lexicon_item.AiAssistantLexiconItem(
                                ai_assistant_id = 56, 
                                deleted_at = 56, 
                                id = 56, 
                                order = 56, 
                                pronounciation = '', 
                                term = '', )
                            ], 
                        name = '', 
                        prefer_voice = True, 
                        system_prompt = '', 
                        system_prompt_support = '', 
                        system_prompt_tutor = '', 
                        type = 'portal', 
                        voice_id = 56, ), 
                    credentials = ai_assistant_server_connector.models.emphemeral_credentials.EmphemeralCredentials(
                        ephemeral_token = '', ), )
            )
        else:
            return ResponseWrapperAIAssistantSessionStart(
                done = True,
        )
        """

    def testResponseWrapperAIAssistantSessionStart(self):
        """Test ResponseWrapperAIAssistantSessionStart"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from ai_assistant_server_connector.models.search_result import SearchResult

class RagQueryResponse(BaseModel):
    """
    RagQueryResponse
    """
    available_free: conlist(SearchResult) = Field(...)
    available_paid: conlist(SearchResult) = Field(...)
    owned: conlist(SearchResult) = Field(...)
    __properties = ["available_free", "available_paid", "owned"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RagQueryResponse:
        """Create an instance of RagQueryResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in available_free (list)
        _items = []
        if self.available_free:
            for _item in self.available_free:
                if _item:
                    _items.append(_item.to_dict())
            _dict['available_free'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in available_paid (list)
        _items = []
        if self.available_paid:
            for _item in self.available_paid:
                if _item:
                    _items.append(_item.to_dict())
            _dict['available_paid'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in owned (list)
        _items = []
        if self.owned:
            for _item in self.owned:
                if _item:
                    _items.append(_item.to_dict())
            _dict['owned'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RagQueryResponse:
        """Create an instance of RagQueryResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RagQueryResponse.parse_obj(obj)

        _obj = RagQueryResponse.parse_obj({
            "available_free": [SearchResult.from_dict(_item) for _item in obj.get("available_free")] if obj.get("available_free") is not None else None,
            "available_paid": [SearchResult.from_dict(_item) for _item in obj.get("available_paid")] if obj.get("available_paid") is not None else None,
            "owned": [SearchResult.from_dict(_item) for _item in obj.get("owned")] if obj.get("owned") is not None else None
        })
        return _obj


